pix_sicoob library

Classes

Pagador
A class representing a Payer
Pix
A class representing a PIX payment.
PixSicoob
The main class that provides the Pix Sicoob API functionalities.
Token
This class represents an OAuth2 access token, which is used for client authentication and authorization.

Exceptions / Errors

PixException
The base class for all exceptions related to the Pix feature.
SicoobApiException
An exception representing an error response from the Sicoob API.
SicoobCertificateException
Exception thrown when an error occurs with the certificate used for Pix
SicoobHttpException
Exception thrown when an HTTP request fails.
SicoobUnknownException
An exception that represents an unknown error in the Pix Sicoob API.