pix_sicoob library
Classes
Exceptions / Errors
- PixException
- The base class for all exceptions related to the Pix feature.
- SicoobApiException
- An exception representing an error response from the Sicoob API.
- SicoobCertificateException
- Exception thrown when an error occurs with the certificate used for Pix
- SicoobHttpException
- Exception thrown when an HTTP request fails.
- SicoobUnknownException
- An exception that represents an unknown error in the Pix Sicoob API.